@@ -60,6 +60,7 @@ lilypond_keywords = (
     'layout',
     'with',
     'context',
+    'tagGroup', # since 2.20
 )
 
 
@@ -84,6 +85,7 @@ lilypond_music_commands = (
     'applyMusic',
     'applyOutput',
     'appoggiatura',
+    'arabicStringNumbers', # since 2.20
     'arpeggio',
     'arpeggioArrowDown',
     'arpeggioArrowUp',
@@ -108,6 +110,7 @@ lilypond_music_commands = (
     'bassFigureStaffAlignmentDown',
     'bassFigureStaffAlignmentNeutral',
     'bassFigureStaffAlignmentUp',
+    'beamExceptions', # since 2.20
     'bendAfter',
     'blackTriangleMarkup',
     'bookOutputName',
@@ -247,6 +250,7 @@ lilypond_music_commands = (
     'lyricmode',
     'lyrics',
     'lyricsto',
+    'magnifyMusic', # since 2.20
     'maininput',
     'majorSevenSymbol',
     'makeClusters',
@@ -332,6 +336,7 @@ lilypond_music_commands = (
     'revert',
     'rfz',
     'rightHandFinger',
+    'romanStringNumbers', # since 2.20
     'sacredHarpHeads',
     'sacredHarpHeadsMinor',
     'scaleDurations',
@@ -470,7 +475,7 @@ ornaments = (
     'reverseturn',
     'trill',
 )
-   
+
 
 fermatas = (
     'shortfermata',
@@ -513,15 +518,15 @@ ancient_scripts = (
 
 
 modes = (
-    'major',     
-    'minor',     
-    'ionian',    
-    'dorian',    
-    'phrygian',  
-    'lydian',    
+    'major',
+    'minor',
+    'ionian',
+    'dorian',
+    'phrygian',
+    'lydian',
     'mixolydian',
-    'aeolian',   
-    'locrian',   
+    'aeolian',
+    'locrian',
 )
 
 
@@ -574,6 +579,7 @@ markupcommands_nargs = (
     'italic',
     'justify',
     'justify-field',
+    'justify-line', #since 2.20
     'justify-string',
     'large',
     'larger',
@@ -592,6 +598,8 @@ markupcommands_nargs = (
     'normal-text',
     'number',
     'oval', # since 2.18
+    'overlay', # since 2.20
+    'overtie', # since 2.20
     'postscript',
     'right-align',
     'right-brace',
@@ -610,12 +618,14 @@ markupcommands_nargs = (
     'super',
     'teeny',
     'text',
+    'tie', # since 2.20
     'tied-lyric',
     'tiny',
     'transparent',
     'triangle',
     'typewriter',
     'underline',
+    'undertie', # since 2.20
     'upright',
     'vcenter',
     'vspace',
@@ -655,12 +665,14 @@ markupcommands_nargs = (
     'with-link',
     'with-url',
     'woodwind-diagram',
+    'with-dimensions-from', # since 2.20
 ),
 # three arguments
 (
     'arrow-head',
     'beam',
     'draw-circle',
+    'draw-squiggle-line', # since 2.20
     'epsfile',
     'filled-box',
     'general-align',
@@ -982,7 +994,7 @@ headervariables = (
     'texidoc',
     'footer',
 )
-    
+
 
 papervariables = (
     # fixed vertical
@@ -991,7 +1003,7 @@ papervariables = (
     'bottom-margin',
     'ragged-bottom',
     'ragged-last-bottom',
-    
+
     # horizontal
     'paper-width',
     'line-width',
@@ -1007,7 +1019,7 @@ papervariables = (
     'horizontal-shift',
     'indent',
     'short-indent',
-    
+
     # flex vertical
     'markup-system-spacing', # the distance between a (title or top-level) markup and the system that follows it.
     'score-markup-spacing',  # the distance between the last system of a score and the (title or top-level) markup that follows it.
@@ -1017,7 +1029,7 @@ papervariables = (
     'last-bottom-spacing',   # the distance from the last system or top-level markup on a page to the bottom of the printable area (i.e. the top of the bottom margin).
     'top-system-spacing',    # the distance from the top of the printable area (i.e. the bottom of the top margin) to the first system on a page, when there is no (title or top-level) markup between the two.
     'top-markup-spacing',    # the distance from the top of the printable area (i.e. the bottom of the top margin) to the first (title or top-level) markup on a page, when there is no system between the two.
-    
+
     # line breaking
     'max-systems-per-page',
     'min-systems-per-page',
@@ -1031,21 +1043,21 @@ papervariables = (
     'page-breaking',                 # The page-breaking algorithm to use. Choices are ly:minimal-breaking, ly:page-turn-breaking, and ly:optimal-breaking.
     'page-breaking-system-system-spacing', # Tricks the page breaker into thinking that system-system-spacing is set to something different than it really is. For example, if page-breaking-system-system-spacing #'padding is set to something substantially larger than system-system-spacing #'padding, then the page-breaker will put fewer systems on each page. Default: unset.
     'page-count',                    # The number of pages to be used for a score, unset by default.
-    
+
     # page numbering
     'auto-first-page-number',
     'first-page-number',
     'print-first-page-number',
     'print-page-number',
-    
+
     # misc
     'page-spacing-weight',
     'print-all-headers',
     'system-separator-markup',
-    
+
     # debugging
     'annotate-spacing',
-    
+
     # different markups
     'bookTitleMarkup',
     'evenFooterMarkup',
@@ -1055,10 +1067,10 @@ papervariables = (
     'scoreTitleMarkup',
     'tocItemMarkup',
     'tocTitleMarkup',
-    
+
     # fonts
     'fonts',
-    
+
     # undocumented?
     #'blank-after-score-page-force',
     #'force-assignment',
@@ -1098,6 +1110,8 @@ accidentalstyles = (
     'modern-voice-cautionary',
     'piano',
     'piano-cautionary',
+    'choral', # since 2.20
+    'choral-cautionary', # since 2.20
     'neo-modern',
     'neo-modern-cautionary',
     'neo-modern-voice',
@@ -1131,7 +1145,7 @@ clefs_plain = (
     'varpercussion',    # since 2.19
     'violin',
 )
-    
+
 
 clefs = clefs_plain + (
     'treble_8',
